==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/floppy/demo_dialogs_nl.lua <==

dialogId("dlg-x-poster1", "font_orange", "THE GREATEST EARTHQUAKE SINCE 1990")
dialogStr("DE GROOTSTE AARDBEVING SINDS 1990")


dialogId("dlg-x-poster2", "font_orange", "when Dragon's Lair was issued, Rules for beginners, version 1.0.")
dialogStr("Toen Dragon's Lair werd uitgebracht, Regels voor beginners, versie 1.0.")


dialogId("dlg-x-poster4", "font_orange", "The world of role-playing games will soon change forever.")
dialogStr("De wereld van de computerrollenspellen zal nooit meer hetzelfde zijn.")


dialogId("dlg-x-poster5", "font_orange", "Dragon's Lair Plus is not only a new version.")
dialogStr("Dragon's Lair Plus is niet zomaar een nieuwe versie.")


dialogId("dlg-x-poster6", "font_orange", "It's a new game.")
dialogStr("Het is een nieuw spel.")


dialogId("dlg-x-poster7", "font_orange", "Plenty of new possibilities. New occupations. New system of character creation, where, instead of your lives, your skills grow. New elegant mechanism of playing.")
dialogStr("Met veel nieuwe mogelijkheiden. Nieuwe beroepen. Een nieuw systeem voor het maken van personages, waarin, in plaats van meer levens krijg, beter wordt. Een nieuwe en elegante manier van spelen.")


dialogId("dlg-x-poster8", "font_orange", "A game for 21. century.")
dialogStr("Een spel voor de eenentwintigste eeuw.")


dialogId("dlg-x-poster9", "font_orange", "GAMES HAVE CHANGED")
dialogStr("COMPUTERSPELLEN GAAN VERANDEREN")


dialogId("dlg-x-poster10", "font_poster", "This is what we get from the computer after inserting the waterproof diskette that was found during our investigation of secret criminal organisation.")
dialogStr("Dat is wat we uit de computer krijgen waar we de watervaste diskette in hebben gestopt die we tijdens ons onderzoek van de criminele organisatie hebben gevonden.")


dialogId("dlg-x-poster11", "font_poster", "We are shocked. Do not let journalists know it.")
dialogStr("Het is diep schokkend. Zorg dat de pers er niet achter komt.")


dialogId("dlg-x-poster12", "font_poster", "You must prevent the panic.")
dialogStr("Jullie moeten algemene paniek zien te voorkomen.")


dialogId("dlg-x-poster13", "font_poster", "And subscribe two copies for us.")
dialogStr("En bestel twee kopieën voor ons.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/floppy/demo_dialogs_nl.lua <==

dialogId("dlg-x-poster1", "font_orange", "THE GREATEST EARTHQUAKE SINCE 1990")
dialogStr("DE GROOTSTE AARDBEVING SINDS 1990")


dialogId("dlg-x-poster2", "font_orange", "when Dragon's Lair was issued, Rules for beginners, version 1.0.")
dialogStr("Toen Dragon's Lair werd uitgebracht, Regels voor beginners, versie 1.0.")


dialogId("dlg-x-poster4", "font_orange", "The world of role-playing games will soon change forever.")
dialogStr("De wereld van de computerrollenspellen zal nooit meer hetzelfde zijn.")


dialogId("dlg-x-poster5", "font_orange", "Dragon's Lair Plus is not only a new version.")
dialogStr("Dragon's Lair Plus is niet zomaar een nieuwe versie.")


dialogId("dlg-x-poster6", "font_orange", "It's a new game.")
dialogStr("Het is een nieuw spel.")


dialogId("dlg-x-poster7", "font_orange", "Plenty of new possibilities. New occupations. New system of character creation, where, instead of your lives, your skills grow. New elegant mechanism of playing.")
dialogStr("Met veel nieuwe mogelijkheiden. Nieuwe beroepen. Een nieuw systeem voor het maken van personages, waarin je, in plaats van meer levens te krijgen, beter wordt. Een nieuwe en elegante manier van spelen.")


dialogId("dlg-x-poster8", "font_orange", "A game for 21. century.")
dialogStr("Een spel voor de eenentwintigste eeuw.")


dialogId("dlg-x-poster9", "font_orange", "GAMES HAVE CHANGED")
dialogStr("COMPUTERSPELLEN GAAN VERANDEREN")


dialogId("dlg-x-poster10", "font_poster", "This is what we get from the computer after inserting the waterproof diskette that was found during our investigation of secret criminal organisation.")
dialogStr("Dat is wat we uit de computer krijgen waar we de watervaste diskette in hebben gestopt die we tijdens ons onderzoek van de criminele organisatie hebben gevonden.")


dialogId("dlg-x-poster11", "font_poster", "We are shocked. Do not let journalists know it.")
dialogStr("Het is diep schokkend. Zorg dat de pers er niet achter komt.")


dialogId("dlg-x-poster12", "font_poster", "You must prevent the panic.")
dialogStr("Jullie moeten paniek onder de bevolking zien te voorkomen.")


dialogId("dlg-x-poster13", "font_poster", "And subscribe two copies for us.")
dialogStr("En bestel twee kopieën voor ons.")
